@@ -1,4 +1,4 @@
-use crate::components::prelude::*;
+use crate::innerlude::*;
 
 pure_props! {
     /// Bulma [Box](https://bulma.io/documentation/elements/box/) Element
